API reference
=============

.. automodule:: dsps.sed
    :members: calc_rest_sed_sfh_table_lognormal_mdf, calc_rest_sed_sfh_table_met_table

.. automodule:: dsps.photometry
    :members: calc_rest_mag, calc_obs_mag

.. automodule:: dsps.data_loaders
    :members: load_ssp_templates, load_transmission_curve
